@@ -8,7 +8,6 @@ from .scpi_exceptions import ScpiErrorException
 
 logger = logging.getLogger(__name__)
 
-
 class ScpiDevice(object):
     resource: Optional[ScpiResource] = None
     transport: Optional[ScpiTransports] = None
@@ -38,14 +37,20 @@ class ScpiDevice(object):
         if param is not None:
             command = ' '.join([header, param.compose()])
 
-        self.transport.writeline(command)
+        try:
+            self.transport.writeline(command)
 
-        if result is not type(None):
-            response = result.parse(self.transport)
+            if result is not type(None):
+                response = result.parse(self.transport)
+
+            logger.info(
+                f'exec [{type(param).__name__} -> {result.__name__}]: ' +
+                f'{str(header.encode())[1:]} ({str(param)}) -> ({str(response)})')
+        except Exception as e:
+            logger.error(
+                f'exec [{type(param).__name__} -> {result.__name__}]: ' +
+                f'{str(header.encode())[1:]} ({str(param)}) -> ({str(response)}) [{repr(e)}]')
 
-        logger.info(
-            f'exec [{type(param).__name__} -> {result.__name__}]: ' +
-            f'{str(header.encode())[1:]} ({str(param)}) -> ({str(response)})')
         return response
 
     def check_error(self) -> Optional[ScpiEvent]:
