@@ -1,5 +1,6 @@
 import abc
 from typing import *
+from typing import IO
 
 
 class ScpiTypeBase(object):
@@ -18,7 +19,7 @@ class ScpiTypeBase(object):
 
     @classmethod
     @abc.abstractmethod
-    def parse(cls, stream):
+    def parse(cls, stream: IO):
         """Parses SCPI "Device talking Elements" into an internal representation"""
         raise NotImplementedError("Please Implement this method")
 
