@@ -252,7 +252,7 @@ class ScpiArbBlock(ScpiTypeBase):
     def compose(self) -> str:
         length = f'{len(self._data)}'
         head = f'{len(length)}'
-        return '#' + head + length + self._data.decode('iso-8859-15')
+        return '#' + head + length + self._data.decode('utf8')
 
     @classmethod
     def parse(cls, transport: IO):
